import{d as r,r as a,o as c,eP as l,b as f,et as u,eC as p,eN as y}from"./outputWidgets.b9aa154a.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="4e164112-23fb-4cd0-9f96-2d6dcd086c31",e._sentryDebugIdIdentifier="sentry-dbid-4e164112-23fb-4cd0-9f96-2d6dcd086c31")}catch{}})();const m=r({__name:"ActionButton",props:{action:{},displayName:{}},emits:["click"],setup(e,{emit:n}){const o=e,s=a(null);return c(()=>{s.value&&o.action.setElement(s.value),l.addAction(o.action)}),(d,t)=>(f(),u("button",{ref_key:"element",ref:s,class:"next-button",onClick:t[0]||(t[0]=i=>n("click")),onKeydown:t[1]||(t[1]=y(i=>n("click"),["enter"]))},p(d.displayName),545))}});export{m as _};
//# sourceMappingURL=ActionButton.vue_vue_type_script_setup_true_lang.469e0f4c.js.map
