import{d as y,ez as g,eA as v,r as k,b as r,c as s,w as a,u as e,f as c,ew as i}from"./outputWidgets.b9aa154a.js";import{S as h,L as w}from"./SmartConsole.7bdfdf85.js";import{a as B}from"./asyncComputed.9bda3979.js";import{H as C}from"./hooks.d7d8bca7.js";import{_ as H}from"./SaveButton.vue_vue_type_script_setup_true_lang.c5ad27ab.js";import{_ as I}from"./DocsButton.vue_vue_type_script_setup_true_lang.6e7114de.js";import{B as S}from"./BaseLayout.ddf81c1c.js";import{_ as T,a as x}from"./HookSettings.vue_vue_type_script_setup_true_lang.7a205cc1.js";import{c as A}from"./index.74d4e484.js";import{A as _,T as D}from"./TabPane.3d00468a.js";import"./forms.4a73365d.js";import"./activeRecord.8939db5d.js";import"./pubsub.967f482a.js";import"./dashes.23df7fa5.js";import"./index.ade1bec6.js";import"./jobs.193d98cf.js";import"./workspaces.157f78cb.js";import"./icons.4ed83c58.js";import"./Title.6cd833fd.js";import"./index.23063916.js";import"./uuid.230991bb.js";import"./ant-design.a6411a07.js";import"./index.eb23b22d.js";import"./index.6b140cad.js";import"./index.45ef6041.js";import"./index.ea68e603.js";import"./Form.55f226f4.js";(function(){try{var n=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},m=new Error().stack;m&&(n._sentryDebugIds=n._sentryDebugIds||{},n._sentryDebugIds[m]="b82bc66e-b6b8-42cf-9f41-4da49c213850",n._sentryDebugIdIdentifier="sentry-dbid-b82bc66e-b6b8-42cf-9f41-4da49c213850")}catch{}})();const ne=y({__name:"HookEditor",setup(n){const m=g(),l=v(),f=k(null),o=k("test");function b(){m.push({name:"hooks"})}const{result:t}=B(()=>C.get(l.params.hookPath)),p=w.create();return(R,d)=>(r(),s(S,null,{navbar:a(()=>[e(t)?(r(),s(e(A),{key:0,title:e(t).title,onBack:b},{footer:a(()=>[c(e(D),{"active-key":o.value,"onUpdate:activeKey":d[0]||(d[0]=u=>o.value=u)},{default:a(()=>[c(e(_),{key:"test",tab:"Test"}),c(e(_),{key:"settings",tab:"Settings"})]),_:1},8,["active-key"])]),extra:a(()=>[c(I,{path:"hooks"}),o.value==="settings"?(r(),s(H,{key:0,model:e(t)},null,8,["model"])):i("",!0)]),_:1},8,["title"])):i("",!0)]),content:a(()=>[e(t)&&o.value==="test"?(r(),s(T,{key:0,ref_key:"tester",ref:f,hook:e(t),"log-service":e(p)},null,8,["hook","log-service"])):i("",!0),e(t)&&o.value==="settings"?(r(),s(x,{key:1,hook:e(t)},null,8,["hook"])):i("",!0)]),footer:a(()=>{var u;return[e(t)&&o.value==="test"?(r(),s(h,{key:0,runtime:"forms","log-service":e(p),onRestart:(u=f.value)==null?void 0:u.runHook},null,8,["log-service","onRestart"])):i("",!0)]}),_:1}))}});export{ne as default};
//# sourceMappingURL=HookEditor.bb88bc0b.js.map
