import{d,eA as b,J as c,a as f,b as g,c as v,w as i,f as s}from"./outputWidgets.b9aa154a.js";import{B as _}from"./BaseLayout.ddf81c1c.js";import{a as h}from"./asyncComputed.9bda3979.js";import{P as y}from"./project.c2b2df99.js";import"./console.ee73e2aa.js";import{O as z}from"./organization.b0d8127b.js";import"./index.4d631048.js";import{_ as j}from"./Navbar.vue_vue_type_script_setup_true_lang.905048c8.js";import{S as I}from"./Sidebar.c207837c.js";import{I as w,J as k,K as B,L as P,M as $,N as C,O as M,F as x,G as D,H as L}from"./icons.4ed83c58.js";import"./gateway.5aa82c5f.js";import"./activeRecord.8939db5d.js";import"./pubsub.967f482a.js";import"./index.ade1bec6.js";import"./Form.55f226f4.js";import"./Title.6cd833fd.js";import"./index.74d4e484.js";import"./index.6b140cad.js";import"./index.29aa7167.js";import"./dayjs.d2a09bae.js";import"./index.ea68e603.js";import"./index.bb85a084.js";import"./TabPane.3d00468a.js";import"./index.ab1855db.js";import"./index.14f3ef13.js";import"./index.eb23b22d.js";import"./index.45ef6041.js";import"./index.45ac8fb9.js";import"./index.004b987c.js";import"./index.23063916.js";import"./index.55488473.js";import"./logo.084e5d7c.js";import"./Tooltip.634a9437.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[r]="25b042b7-05ff-4f70-8ff3-fd4b62d82bb7",t._sentryDebugIdIdentifier="sentry-dbid-25b042b7-05ff-4f70-8ff3-fd4b62d82bb7")}catch{}})();const bo=d({__name:"Project",setup(t){const p=b().params.projectId,{result:o}=h(()=>y.get(p).then(async a=>{const e=await z.get(a.organizationId);return{project:a,organization:e}})),l=c(()=>{var a,e,n,m;return((a=o.value)==null?void 0:a.organization)&&o.value.project?[{label:"My organizations",path:"/organizations"},{label:(n=(e=o.value)==null?void 0:e.organization)==null?void 0:n.name,path:`/organizations/${(m=o.value)==null?void 0:m.organization.id}`},{label:o.value.project.name,path:`/projects/${o.value.project.id}`}]:void 0}),u=c(()=>{var a;return(a=o.value)!=null&&a.project?[{name:"Project",items:[{name:"Builds",path:"builds",icon:w},{name:"Connectors",path:"connectors",icon:k},{name:"Tables",path:"tables",icon:B},{name:"API Keys",path:"api-keys",icon:P},{name:"Env Vars",path:"env-vars",icon:$},{name:"Logs",icon:C,path:"logs",beta:!0},{name:"Settings",icon:M,path:"settings"}]},{name:"Organization",items:[{name:"Projects",icon:x,path:`/organizations/${o.value.project.organizationId}/projects`},{name:"Members",icon:D,path:`/organizations/${o.value.project.organizationId}/members`},{name:"Billing",icon:L,path:`/organizations/${o.value.project.organizationId}/billing`,unavailable:!0}]}]:[]});return(a,e)=>{const n=f("router-view");return g(),v(_,null,{content:i(()=>[s(n)]),navbar:i(()=>[s(j,{class:"nav",breadcrumb:l.value},null,8,["breadcrumb"])]),sidebar:i(()=>[s(I,{class:"sidebar",sections:u.value},null,8,["sections"])]),_:1})}}});export{bo as default};
//# sourceMappingURL=Project.706d55e0.js.map
