import"./outputWidgets.b9aa154a.js";(function(){try{var x=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(x._sentryDebugIds=x._sentryDebugIds||{},x._sentryDebugIds[n]="f525c3d6-fdf6-4354-a5b0-867fa704a828",x._sentryDebugIdIdentifier="sentry-dbid-f525c3d6-fdf6-4354-a5b0-867fa704a828")}catch{}})();const r=()=>"xxxxxxxx-xxxx-4xxx-yxxx-xxxxxxxxxxxx".replace(/[xy]/g,function(x){const n=Math.random()*16|0;return(x=="x"?n:n&3|8).toString(16)}),d=()=>Math.random().toString(36).slice(2);export{d as r,r as u};
//# sourceMappingURL=uuid.230991bb.js.map
