import{M as r}from"./Modal.e6afe637.js";import{d as a,H as d,r as _,a as c,b as f,et as l,f as n,w as i,bw as m,e as u,x as p}from"./outputWidgets.b9aa154a.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="940d8974-845d-48fd-a9fe-459d8ae1956f",e._sentryDebugIdIdentifier="sentry-dbid-940d8974-845d-48fd-a9fe-459d8ae1956f")}catch{}})();const y=["src"],b=a({__name:"Home",setup(e){const o=d({onboardingForm:""}),t=_(null);return(g,w)=>{const s=c("router-view");return f(),l(m,null,[n(s,{class:"router"}),n(r,{ref_key:"modal",ref:t},{content:i(()=>[u("iframe",{class:"form",src:o.onboardingForm},null,8,y)]),_:1},512)],64)}}});const I=p(b,[["__scopeId","data-v-7e290e34"]]);export{I as default};
//# sourceMappingURL=Home.da58e209.js.map
