import{x as t,b as d,et as s}from"./outputWidgets.b9aa154a.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="fe3ad46a-912f-46e0-9bb1-9ddd227cef9d",e._sentryDebugIdIdentifier="sentry-dbid-fe3ad46a-912f-46e0-9bb1-9ddd227cef9d")}catch{}})();const o={},r={class:"organization-settings"};function a(e,n){return d(),s("div",r,"Organization settings")}const c=t(o,[["render",a]]);export{c as default};
//# sourceMappingURL=OrganizationSettings.7365cd3a.js.map
