import{cN as d}from"./outputWidgets.b9aa154a.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="d30cc79f-bae7-4ec2-8746-615ebed0495b",e._sentryDebugIdIdentifier="sentry-dbid-d30cc79f-bae7-4ec2-8746-615ebed0495b")}catch{}})();const t=(e,r)=>{d.error({message:e,description:r})};export{t as p};
//# sourceMappingURL=popupNotifcation.77a0c0ca.js.map
