import{R as n}from"./Title.6cd833fd.js";import{F as d}from"./outputWidgets.b9aa154a.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="20ec7781-f36e-4a59-b2c1-9b280d5f0724",e._sentryDebugIdIdentifier="sentry-dbid-20ec7781-f36e-4a59-b2c1-9b280d5f0724")}catch{}})();const s=d(n);export{s as A};
//# sourceMappingURL=index.23063916.js.map
