import{C as d}from"./Title.6cd833fd.js";import{F as n}from"./outputWidgets.b9aa154a.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="89f270c1-1989-48f3-9d34-d256a644511f",e._sentryDebugIdIdentifier="sentry-dbid-89f270c1-1989-48f3-9d34-d256a644511f")}catch{}})();const s=n(d);export{s as A};
//# sourceMappingURL=index.14f3ef13.js.map
