import{d as o,b as a,c as r,w as d,b2 as i,u as c,cd as f}from"./outputWidgets.b9aa154a.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="44d45fde-68ff-446b-b674-f111fab7d160",t._sentryDebugIdIdentifier="sentry-dbid-44d45fde-68ff-446b-b674-f111fab7d160")}catch{}})();class p{async get(){return(await fetch("/_editor/api/login")).json()}async create(e){return(await fetch("/_editor/api/login",{method:"POST",headers:{"Content-Type":"application/json"},body:JSON.stringify({token:e})})).json()}async delete(){await fetch("/_editor/api/login",{method:"DELETE"})}}const l=new p,u=o({__name:"DocsButton",props:{path:{}},setup(t){return(e,n)=>{var s;return a(),r(c(f),{class:"docs-button",href:`https://docs.abstra.io/${(s=e.path)!=null?s:""}`,target:"_blank"},{default:d(()=>[i(" Docs ")]),_:1},8,["href"])}}});export{u as _,l};
//# sourceMappingURL=DocsButton.vue_vue_type_script_setup_true_lang.6e7114de.js.map
