import{d as g,ez as v,eA as k,r as b,b as r,c as s,w as a,u as e,f,ew as i}from"./outputWidgets.b9aa154a.js";import{S as w,L as j}from"./SmartConsole.7bdfdf85.js";import{a as I}from"./asyncComputed.9bda3979.js";import{J as B}from"./jobs.193d98cf.js";import{_ as C}from"./SaveButton.vue_vue_type_script_setup_true_lang.c5ad27ab.js";import{_ as S}from"./DocsButton.vue_vue_type_script_setup_true_lang.6e7114de.js";import{B as T}from"./BaseLayout.ddf81c1c.js";import{_ as x,a as A}from"./JobSettings.vue_vue_type_script_setup_true_lang.8407d250.js";import{c as D}from"./index.74d4e484.js";import{A as _,T as R}from"./TabPane.3d00468a.js";import"./forms.4a73365d.js";import"./activeRecord.8939db5d.js";import"./pubsub.967f482a.js";import"./dashes.23df7fa5.js";import"./index.ade1bec6.js";import"./hooks.d7d8bca7.js";import"./workspaces.157f78cb.js";import"./icons.4ed83c58.js";import"./Title.6cd833fd.js";import"./index.23063916.js";import"./uuid.230991bb.js";import"./ant-design.a6411a07.js";import"./dayjs.d2a09bae.js";import"./index.ea68e603.js";import"./Form.55f226f4.js";import"./index.6b140cad.js";(function(){try{var n=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},m=new Error().stack;m&&(n._sentryDebugIds=n._sentryDebugIds||{},n._sentryDebugIds[m]="90349ff6-9645-42ad-a49e-b32d9bfa75d7",n._sentryDebugIdIdentifier="sentry-dbid-90349ff6-9645-42ad-a49e-b32d9bfa75d7")}catch{}})();const ae=g({__name:"JobEditor",setup(n){const m=v(),l=k(),p=b(null),o=b("test");function y(){m.push({name:"jobs"})}const{result:t}=I(()=>B.get(l.params.jobId)),c=j.create();return($,d)=>(r(),s(T,null,{navbar:a(()=>[e(t)?(r(),s(e(D),{key:0,title:e(t).title,onBack:y},{footer:a(()=>[f(e(R),{"active-key":o.value,"onUpdate:activeKey":d[0]||(d[0]=u=>o.value=u)},{default:a(()=>[f(e(_),{key:"test",tab:"Test"}),f(e(_),{key:"settings",tab:"Settings"})]),_:1},8,["active-key"])]),extra:a(()=>[f(S),o.value==="settings"?(r(),s(C,{key:0,model:e(t)},null,8,["model"])):i("",!0)]),_:1},8,["title"])):i("",!0)]),content:a(()=>[e(t)&&o.value==="test"?(r(),s(x,{key:0,ref_key:"tester",ref:p,job:e(t),"log-service":e(c)},null,8,["job","log-service"])):i("",!0),e(t)&&o.value==="settings"?(r(),s(A,{key:1,job:e(t)},null,8,["job"])):i("",!0)]),footer:a(()=>{var u;return[e(t)&&o.value==="test"?(r(),s(w,{key:0,runtime:"forms","log-service":e(c),onRestart:(u=p.value)==null?void 0:u.test},null,8,["log-service","onRestart"])):i("",!0)]}),_:1}))}});export{ae as default};
//# sourceMappingURL=JobEditor.4411e4d8.js.map
