import{x as o,a,b as i,c,g as p,h as _,_ as d,i as u,T as l,j as h,P as f,C as m,M as y,s as b,k as s,l as g,m as v,n as w,p as I}from"./outputWidgets.b9aa154a.js";import{u as k}from"./index.a3419ef4.js";import"./pubsub.967f482a.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="60614239-ee11-4b8a-b385-c790473efe28",e._sentryDebugIdIdentifier="sentry-dbid-60614239-ee11-4b8a-b385-c790473efe28")}catch{}})();const x={};function A(e,t){const r=a("router-view");return i(),c(r,{style:{"min-height":"100vh","box-sizing":"border-box",width:"100%"}})}const D=o(x,[["render",A]]),n=p({history:_("/"),routes:[{path:"/:path(.*)*",name:"player",component:()=>d(()=>import("./Player.f89ad114.js"),["assets/Player.f89ad114.js","assets/index.ade1bec6.js","assets/outputWidgets.b9aa154a.js","assets/outputWidgets.8ce475af.css","assets/uuid.230991bb.js","assets/broker.4016214f.js","assets/index.a3419ef4.js","assets/pubsub.967f482a.js","assets/executeJs.99fc5689.js","assets/icons.4ed83c58.js","assets/CircularLoading.06bdbb4b.js","assets/CircularLoading.f81b57b4.css","assets/PlayerNavbar.2c80c9e8.js","assets/PlayerNavbar.76a7eb2f.css","assets/Steps.b2e658b4.js","assets/Steps.998aa76d.css","assets/Modal.e6afe637.js","assets/Modal.5aaf8eba.css","assets/executeJs.dfa3b35d.css","assets/WidgetsFrame.8ed370e1.js","assets/WidgetsFrame.0816a5f5.css","assets/ActionButton.vue_vue_type_script_setup_true_lang.469e0f4c.js","assets/broker.ac4594bd.css","assets/DashPlayer.bf75e65d.js","assets/geometryUtils.8f27911e.js","assets/DashPlayer.4868beea.css","assets/asyncComputed.9bda3979.js","assets/Player.77337a17.css"])}],scrollBehavior(e){if(e.hash)return{el:e.hash}}});class P{static init(){setInterval(()=>fetch("/_healthcheck"),20*1e3)}}(async()=>{await k();const e=u({render:()=>g(D)});l.init(),h(e,n),P.init(),e.use(n),e.use(f),e.mount("#app"),e.component("VSelect",m),e.component("Markdown",y),e.component("Message",b),s(e,v),s(e,w),s(e,I)})();
//# sourceMappingURL=player.a713b25d.js.map
