import{u as s}from"./icons.4ed83c58.js";import{d as c,a as r,b as i,et as d,f as _,u as l,b2 as u,x as f}from"./outputWidgets.b9aa154a.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="319a1cc7-2794-40a5-9bde-af0b506bac65",e._sentryDebugIdIdentifier="sentry-dbid-319a1cc7-2794-40a5-9bde-af0b506bac65")}catch{}})();const b=c({__name:"BackButton",emits:["exitFullscreenPreview"],setup(e,{emit:t}){return(a,n)=>{const o=r("icon");return i(),d("button",{class:"back-btn",onClick:n[0]||(n[0]=p=>t("exitFullscreenPreview"))},[_(o,{class:"icon",path:l(s),width:"20",height:"20",fill:"#5A677A"},null,8,["path"]),u(" Editor ")])}}});const w=f(b,[["__scopeId","data-v-eaeb3a6e"]]);export{w as B};
//# sourceMappingURL=BackButton.45960f8e.js.map
