import{d as b,eA as u,J as f,b as y,c as _,u as g}from"./outputWidgets.b9aa154a.js";import{a as w}from"./asyncComputed.9bda3979.js";import"./console.ee73e2aa.js";import{M as m}from"./member.1a56dc57.js";import"./index.4d631048.js";import{_ as I}from"./CrudView.vue_vue_type_script_setup_true_lang.8866a12f.js";import"./index.ade1bec6.js";import"./Form.55f226f4.js";import"./Title.6cd833fd.js";import"./index.74d4e484.js";import"./index.6b140cad.js";import"./index.29aa7167.js";import"./dayjs.d2a09bae.js";import"./index.ea68e603.js";import"./index.bb85a084.js";import"./TabPane.3d00468a.js";import"./index.ab1855db.js";import"./index.14f3ef13.js";import"./index.eb23b22d.js";import"./index.45ef6041.js";import"./index.45ac8fb9.js";import"./index.004b987c.js";import"./index.23063916.js";import"./index.55488473.js";import"./gateway.5aa82c5f.js";import"./activeRecord.8939db5d.js";import"./pubsub.967f482a.js";import"./icons.4ed83c58.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="2be4bed2-cf68-46f6-b3e7-4e584a1d1069",e._sentryDebugIdIdentifier="sentry-dbid-2be4bed2-cf68-46f6-b3e7-4e584a1d1069")}catch{}})();const V=b({__name:"Members",setup(e){const r=u().params.organizationId,n=[{key:"email",label:"Email"}],s=async t=>{await m.create(r,t.email),d()},{loading:p,result:l,refetch:d}=w(()=>m.list(r)),c=f(()=>{var t,i;return{columns:[{name:"Email"},{name:"Role"}],rows:(i=(t=l.value)==null?void 0:t.map(a=>({key:a.email,cells:[{text:a.email},{text:a.role}]})))!=null?i:[]}});return(t,i)=>(y(),_(I,{"entity-name":"members",loading:g(p),title:"Organization members",description:"List all organization members.","empty-title":"No members yet",table:c.value,"create-button-text":"Add members",fields:n,onCreate:s},null,8,["loading","table"]))}});export{V as default};
//# sourceMappingURL=Members.6f78f405.js.map
